@@ -73,6 +73,7 @@ def run():
     parser.add_argument('--endpoint', help="Compile service endpoint.", type=str)
     parser.add_argument('--sphelp', help="Sandpiper help.", nargs=0, action='sphelp')
     parser.add_argument('--outdir', help="Output directory.", type=str)
+    parser.add_argument('--sv_url_inc', help="Return the sv_url_inc directory with the response. The folder contains the files pulled by the URl include macros.", action='store_true')
     parser.add_argument('sandpiper_args', type=str, nargs='*', help='Arguments to be passed to Sanpiper.')
     args, unknown = parser.parse_known_args()
 
@@ -128,6 +129,8 @@ def run():
             files=(
                 ('args', (None, "-i " + Path(top).name + ' ' + ' ' + tlv_output + ' ' + additional_args + ' ' \
                           + sandpiper_args)),
+                ('IAgreeToSLA', (None, "true")),
+                ('sv_url_inc', (None, "true" if args.sv_url_inc==True else "false")),
                 ('context', ('context.zip', zip_buffer.getvalue())),
             ),
             stream=True
@@ -161,6 +164,7 @@ def run():
         if file.startswith(compile_id + '/'):
             filename = os.path.basename(file)
             source = z.open(file)
+            os.makedirs(outdir, exist_ok=True)
             target = open(os.path.join(outdir, filename), "wb")
             with source, target:
                 shutil.copyfileobj(source, target)
